# Changelog

## 0.2.4 (2024-11-12)

Full Changelog: [v0.2.3...v0.2.4](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.3...v0.2.4)

### Features

* **api:** manual updates ([#53](https://github.com/lastmile-ai/lastmile-python/issues/53)) ([df3c8bd](https://github.com/lastmile-ai/lastmile-python/commit/df3c8bd97623819c59942df7dee01510d5a12a05))
* **api:** manual updates ([#56](https://github.com/lastmile-ai/lastmile-python/issues/56)) ([3c0537a](https://github.com/lastmile-ai/lastmile-python/commit/3c0537a0873a3c6e51115a54ad75468cabc31978))
* nov_12_230 ([817ce2c](https://github.com/lastmile-ai/lastmile-python/commit/817ce2c4c035613cc50129b0af6c2ad4db433462))


### Chores

* **internal:** version bump ([#51](https://github.com/lastmile-ai/lastmile-python/issues/51)) ([5259f11](https://github.com/lastmile-ai/lastmile-python/commit/5259f11dac328eaf2cb24413b5cb4964a77388d9))
* rebuild project due to codegen change ([#54](https://github.com/lastmile-ai/lastmile-python/issues/54)) ([9b519c2](https://github.com/lastmile-ai/lastmile-python/commit/9b519c2dc4b54dbc248e5178fc3635572c4f8f6c))
* rebuild project due to codegen change ([#55](https://github.com/lastmile-ai/lastmile-python/issues/55)) ([aa98694](https://github.com/lastmile-ai/lastmile-python/commit/aa98694e29961df298030996f863c0a89d230588))

## 0.2.3 (2024-11-11)

Full Changelog: [v0.2.2...v0.2.3](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.2...v0.2.3)

### Features

* auto_eval ([915aace](https://github.com/lastmile-ai/lastmile-python/commit/915aace1c2a0b986555578c83b91d7bd5aae7973))
* fixup ([503b3c6](https://github.com/lastmile-ai/lastmile-python/commit/503b3c672de06436d5486503f6d908c8723adfeb))

## 0.2.2 (2024-11-11)

Full Changelog: [v0.2.1...v0.2.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.1...v0.2.2)

### Features

* **api:** api update ([#34](https://github.com/lastmile-ai/lastmile-python/issues/34)) ([faffea3](https://github.com/lastmile-ai/lastmile-python/commit/faffea36aa070cf96c2d8ce9aee4e61a5c855bda))
* **api:** api update ([#35](https://github.com/lastmile-ai/lastmile-python/issues/35)) ([4077539](https://github.com/lastmile-ai/lastmile-python/commit/407753915a83c09dfb202ebd1dfcaf988cb62671))
* **api:** api update ([#36](https://github.com/lastmile-ai/lastmile-python/issues/36)) ([8c07793](https://github.com/lastmile-ai/lastmile-python/commit/8c0779359b621804a16a8d7f2b3f6440e699261e))
* **api:** api update ([#38](https://github.com/lastmile-ai/lastmile-python/issues/38)) ([4599222](https://github.com/lastmile-ai/lastmile-python/commit/459922286d7913483d35570de368275f23963b5c))
* **api:** api update ([#39](https://github.com/lastmile-ai/lastmile-python/issues/39)) ([6ab3cc4](https://github.com/lastmile-ai/lastmile-python/commit/6ab3cc48ae8149da333a6648ef899ca228653cfe))
* **api:** api update ([#41](https://github.com/lastmile-ai/lastmile-python/issues/41)) ([64f7ea0](https://github.com/lastmile-ai/lastmile-python/commit/64f7ea0b345cc0e7da0a005b8efea99e4c03251c))
* **api:** api update ([#42](https://github.com/lastmile-ai/lastmile-python/issues/42)) ([1c37dda](https://github.com/lastmile-ai/lastmile-python/commit/1c37dda7d7e6a1840f1b231b7a714875b708e5a3))
* **api:** api update ([#43](https://github.com/lastmile-ai/lastmile-python/issues/43)) ([489b2b3](https://github.com/lastmile-ai/lastmile-python/commit/489b2b37b346dbda8e4a5b6ec857742c86ee950d))
* **api:** api update ([#44](https://github.com/lastmile-ai/lastmile-python/issues/44)) ([6968875](https://github.com/lastmile-ai/lastmile-python/commit/6968875d01cccbdde81d62000af2b6f5ad7fd9e1))
* **api:** api update ([#45](https://github.com/lastmile-ai/lastmile-python/issues/45)) ([a7404a6](https://github.com/lastmile-ai/lastmile-python/commit/a7404a6be5d476b47c301d73eee47a5477c70829))
* **api:** manual updates ([#31](https://github.com/lastmile-ai/lastmile-python/issues/31)) ([94a653d](https://github.com/lastmile-ai/lastmile-python/commit/94a653ddf5aad00d776c7396d02cf8ef74a895fd))
* **api:** manual updates ([#33](https://github.com/lastmile-ai/lastmile-python/issues/33)) ([81ad3b9](https://github.com/lastmile-ai/lastmile-python/commit/81ad3b91ba9b4de495dbda38075e53589cf0f35c))
* **api:** manual updates ([#37](https://github.com/lastmile-ai/lastmile-python/issues/37)) ([bfefa24](https://github.com/lastmile-ai/lastmile-python/commit/bfefa2469b3e922edb96e3d2e978d7f4ececcf73))
* **api:** manual updates ([#40](https://github.com/lastmile-ai/lastmile-python/issues/40)) ([0285b9d](https://github.com/lastmile-ai/lastmile-python/commit/0285b9d5d214485fdd7aab21437e88b777207146))
* **api:** manual updates ([#46](https://github.com/lastmile-ai/lastmile-python/issues/46)) ([d2ffd39](https://github.com/lastmile-ai/lastmile-python/commit/d2ffd39493218abfd84505b27f36fb4528b216c1))


### Chores

* rebuild project due to codegen change ([#47](https://github.com/lastmile-ai/lastmile-python/issues/47)) ([4eacace](https://github.com/lastmile-ai/lastmile-python/commit/4eacaced23cc75ebb13e93d6fa0292728239f4a8))

## 0.2.1 (2024-10-21)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.0...v0.2.1)

### Features

* **api:** api update ([#12](https://github.com/lastmile-ai/lastmile-python/issues/12)) ([1cd0e25](https://github.com/lastmile-ai/lastmile-python/commit/1cd0e25bfe9098ae616f304f5fc4bbfe7b07ac9d))
* **api:** api update ([#13](https://github.com/lastmile-ai/lastmile-python/issues/13)) ([3c13518](https://github.com/lastmile-ai/lastmile-python/commit/3c13518ea1579bc493ad4a115609884165b4d722))
* **api:** api update ([#14](https://github.com/lastmile-ai/lastmile-python/issues/14)) ([b0bd047](https://github.com/lastmile-ai/lastmile-python/commit/b0bd047fe47fff2684aa0c5cb828bfe3ed4c2bee))
* **api:** api update ([#15](https://github.com/lastmile-ai/lastmile-python/issues/15)) ([c7a9bac](https://github.com/lastmile-ai/lastmile-python/commit/c7a9bac766b7c64cc3fafcc48b5340c835ed7cee))
* **api:** api update ([#16](https://github.com/lastmile-ai/lastmile-python/issues/16)) ([76d365f](https://github.com/lastmile-ai/lastmile-python/commit/76d365f6fa238843f1bc07d47f957048ffbbf5bf))
* **api:** api update ([#17](https://github.com/lastmile-ai/lastmile-python/issues/17)) ([56248d2](https://github.com/lastmile-ai/lastmile-python/commit/56248d2dd1924a98c97c1fbfec442e314851b3f9))
* **api:** api update ([#18](https://github.com/lastmile-ai/lastmile-python/issues/18)) ([e8ef17f](https://github.com/lastmile-ai/lastmile-python/commit/e8ef17f4d8e28647ab939adcc182da7b5e582729))
* **api:** api update ([#19](https://github.com/lastmile-ai/lastmile-python/issues/19)) ([b7ead43](https://github.com/lastmile-ai/lastmile-python/commit/b7ead435ef06cb7bc2257fc0071cd22a2ad41993))
* **api:** api update ([#20](https://github.com/lastmile-ai/lastmile-python/issues/20)) ([5592162](https://github.com/lastmile-ai/lastmile-python/commit/55921626bec2884ca5b6592d0cc2896bb5df5f32))
* **api:** api update ([#21](https://github.com/lastmile-ai/lastmile-python/issues/21)) ([125603c](https://github.com/lastmile-ai/lastmile-python/commit/125603caf869b557319cdaea095769823bc61621))
* **api:** api update ([#22](https://github.com/lastmile-ai/lastmile-python/issues/22)) ([7b60dd1](https://github.com/lastmile-ai/lastmile-python/commit/7b60dd1a4e28d6e7feaa88c0fac5f3a1be8d87fb))
* **api:** api update ([#23](https://github.com/lastmile-ai/lastmile-python/issues/23)) ([dfee299](https://github.com/lastmile-ai/lastmile-python/commit/dfee299be547de0e555e31c42791dd330d03be09))
* **api:** api update ([#24](https://github.com/lastmile-ai/lastmile-python/issues/24)) ([e61976a](https://github.com/lastmile-ai/lastmile-python/commit/e61976a75aaee2c89a5d8eb1da8bddb99919e567))
* **api:** api update ([#25](https://github.com/lastmile-ai/lastmile-python/issues/25)) ([d4dafd3](https://github.com/lastmile-ai/lastmile-python/commit/d4dafd327528f2f776eb82866b0fc2477a41dd52))
* **api:** api update ([#26](https://github.com/lastmile-ai/lastmile-python/issues/26)) ([dbfd411](https://github.com/lastmile-ai/lastmile-python/commit/dbfd411b51874a74ba72dcf76e31cc9a2c298ac8))
* **api:** api update ([#27](https://github.com/lastmile-ai/lastmile-python/issues/27)) ([00e8497](https://github.com/lastmile-ai/lastmile-python/commit/00e8497d87eeed272faa0d89914016bf7e823d63))
* **api:** api update ([#28](https://github.com/lastmile-ai/lastmile-python/issues/28)) ([912f2f7](https://github.com/lastmile-ai/lastmile-python/commit/912f2f775bbc38b218b74f6fb5e0df9fa162c46a))
* **api:** OpenAPI spec update via Stainless API ([#10](https://github.com/lastmile-ai/lastmile-python/issues/10)) ([afd69a7](https://github.com/lastmile-ai/lastmile-python/commit/afd69a78c04af9da0508b532f41ce59aac82b5c7))
* **api:** OpenAPI spec update via Stainless API ([#11](https://github.com/lastmile-ai/lastmile-python/issues/11)) ([2ce2481](https://github.com/lastmile-ai/lastmile-python/commit/2ce2481d1c2ce7741dee639b5d9b13a48736676f))
* **api:** OpenAPI spec update via Stainless API ([#8](https://github.com/lastmile-ai/lastmile-python/issues/8)) ([8f9bb2d](https://github.com/lastmile-ai/lastmile-python/commit/8f9bb2dd5ddabfe1d5945d42757bbcefa6c54d88))

## 0.2.0 (2024-10-07)

Full Changelog: [v0.0.1-alpha.0...v0.2.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.0.1-alpha.0...v0.2.0)

### Features

* **api:** manual updates ([bef66b6](https://github.com/lastmile-ai/lastmile-python/commit/bef66b6d9b34c9bbdc682083670b7e72e26e63b3))
* **api:** manual updates ([71c6860](https://github.com/lastmile-ai/lastmile-python/commit/71c68603c7b6ee45798881cd74a255434c4600f5))
* **api:** manual updates ([a4976c3](https://github.com/lastmile-ai/lastmile-python/commit/a4976c3c4265c168347989a6776cb731bd788ec4))
* **api:** manual updates ([7d33740](https://github.com/lastmile-ai/lastmile-python/commit/7d3374067a08e0b2fb6f0c981b83a1924b9c5959))
* **api:** manual updates ([459013a](https://github.com/lastmile-ai/lastmile-python/commit/459013afded932da2ea506a5858f1ad2f5395ff1))
* **api:** manual updates ([ba9baeb](https://github.com/lastmile-ai/lastmile-python/commit/ba9baebe6cecacbc4a1da569b5a8141de5dd86b7))
* **api:** manual updates ([30b1d82](https://github.com/lastmile-ai/lastmile-python/commit/30b1d825b95a35f730affa9dce915e2e9607b502))
* **api:** manual updates ([353997c](https://github.com/lastmile-ai/lastmile-python/commit/353997c164e7bb24e6d04cbe745365b4a59a2e17))
* **api:** manual updates ([d41db01](https://github.com/lastmile-ai/lastmile-python/commit/d41db0146761bfea263c6a888f1efec8264d180a))
* **api:** manual updates ([c8587b0](https://github.com/lastmile-ai/lastmile-python/commit/c8587b04c6f86791103dcccf042176752fe2ddc1))
* **api:** manual updates ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([cac7caf](https://github.com/lastmile-ai/lastmile-python/commit/cac7caf774f9f35a14632ed5a26fa295b52fbdd8))
* **api:** manual updates ([#5](https://github.com/lastmile-ai/lastmile-python/issues/5)) ([eb3ec90](https://github.com/lastmile-ai/lastmile-python/commit/eb3ec90416dcac5299db02d4cd89a5c01742da3d))


### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([47d0fb2](https://github.com/lastmile-ai/lastmile-python/commit/47d0fb29f89f32d6fe59ee16228ea934bd502216))


### Chores

* add repr to PageInfo class ([8d0dde1](https://github.com/lastmile-ai/lastmile-python/commit/8d0dde1480e1eff8a43c89b10ce9399789787411))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([d1a9313](https://github.com/lastmile-ai/lastmile-python/commit/d1a9313a1041302aa553a751b2db3a1777721e9a))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([9e6fc92](https://github.com/lastmile-ai/lastmile-python/commit/9e6fc92ebec5b9e78b2c18938d50583d825a0188))
* update SDK settings ([2eba47f](https://github.com/lastmile-ai/lastmile-python/commit/2eba47ffaf5a53c54ec945a60cfa3f08e47812a0))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([1d43bb0](https://github.com/lastmile-ai/lastmile-python/commit/1d43bb0bda7d80b970b051425be1ab4a844a246f))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([e63c99b](https://github.com/lastmile-ai/lastmile-python/commit/e63c99b3a52e8eb5dc90900f91c32d65b1a747f5))
